@@ -596,7 +596,7 @@ void save_button_pressed( GtkWidget *button) {
     GtkAdjustment *spinner_price_adj, *spinner_number_adj;
 
     int rc=1, response;
-    char *str;
+    const char *str;
 
     GtkTreeIter    iter;
 
@@ -878,7 +878,7 @@ void create_new_list_button() {
 
     //GtkListStore  *store;
     GtkTreeIter    iter;
-    char *pretty_name;
+    const char *pretty_name;
     char sql_name[255];
 
     dialog = gtk_dialog_new_with_buttons ("Create new list",
@@ -949,7 +949,7 @@ void rename_list_button() {
     GtkWidget *dialog, *hbox;
     GtkWidget *label, *text_entry;
     gint response;
-    char *list_name;
+    const char *list_name;
 
     GtkTreeSelection *select;
     char *sqlite_name, *pretty_name;
@@ -1199,7 +1199,7 @@ void edit_data_button() { // pass it the data in question!
 
     gint response;
     //GString *list_name;
-    char *str;
+    const char *str;
     int ret;
 
     GtkTreeSelection *select = gtk_tree_view_get_selection (GTK_TREE_VIEW (appdata->data_view));
@@ -1220,7 +1220,7 @@ void edit_data_button() { // pass it the data in question!
     if (ret==SQLITE_ROW)
         // we got data, otherwise no
 
-        spinner_price_adj = (GtkAdjustment *) gtk_adjustment_new (price, 0.0, 10000000.0, 0.01, 1.0, 1.0);
+    spinner_price_adj = (GtkAdjustment *) gtk_adjustment_new (price, 0.0, 10000000.0, 0.01, 1.0, 1.0);
     spinner_number_adj = (GtkAdjustment *) gtk_adjustment_new (number, 0.0, 10000000.0, 0.1, 1.0, 1.0);
 
     dialog = gtk_dialog_new_with_buttons ("Edit data",
